![build](https://github.com/spedas/pyspedas_examples/workflows/build/badge.svg)
[![codecov](https://codecov.io/gh/spedas/pyspedas_examples/branch/master/graph/badge.svg)](https://codecov.io/gh/spedas/pyspedas_examples)
![PyPI](https://img.shields.io/pypi/v/pyspedas-examples)
![Conda](https://img.shields.io/conda/v/spedas/pyspedas_examples)
![GitHub](https://img.shields.io/github/license/spedas/pyspedas_examples)
![GitHub language count](https://img.shields.io/github/languages/count/spedas/pyspedas_examples)

# pySPEDAS Examples

This project contains examples and turorials for pySPEDAS.

pySPEDAS is a python version of the Space Physics Environment Data Analysis Software ([SPEDAS](http://spedas.org/wiki)) framework.


## Installation

You can install pyspedas_examples using either conda or pip:

```
conda install -c spedas pyspedas_examples

or

pip install pyspedas_examples
```


## Use

You can verify that the installation works, using:

```
from pyspedas_examples.examples.ex_basic import ex_basic
ex_basic()
```

If everything was installed correctly, a plot will appear.


## Additional Information

For pyspedas, see: https://github.com/spedas/pyspedas

For pytplot, see: https://github.com/MAVENSDC/PyTplot

For cdflib, see: https://github.com/MAVENSDC/cdflib

For SPEDAS, see http://spedas.org/
